import 'package:_private_core/constant.dart';

import '_model.dart';

class ProServicesBusiness {
  BusinessDescriptionModel? businessDescription;
  List<ProServiceModel>? services;
  ProServicesBusiness({this.businessDescription, this.services});
  ProServicesBusiness.fromJson(Map<String, dynamic> json) {
    businessDescription =
        BusinessDescriptionModel.fromJson(json["businessDescription"] ?? {});
    if (json["services"] is List) {
      services = (json["services"] as List)
          .map<ProServiceModel>((e) => ProServiceModel.fromJson(e))
          .toList();
    } else {
      services = <ProServiceModel>[];
    }
  }
}

class BusinessDescriptionModel {
  String? description;
  String? pictureUrl1;
  String? pictureUrl2;
  String? pictureUrl3;

  BusinessDescriptionModel(
      {this.description, this.pictureUrl1, this.pictureUrl2, this.pictureUrl3});

  BusinessDescriptionModel.fromJson(Map<String, dynamic> json) {
    if (json["description"] is String) description = json["description"];
    if (json["pictureUrl1"] is String) pictureUrl1 = json["pictureUrl1"];
    if (json["pictureUrl2"] is String) pictureUrl2 = json["pictureUrl2"];
    if (json["pictureUrl3"] is String) pictureUrl3 = json["pictureUrl3"];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data["description"] = description;
    data["pictureUrl1"] = pictureUrl1;
    data["pictureUrl2"] = pictureUrl2;
    data["pictureUrl3"] = pictureUrl3;
    return data;
  }
}

class ProServiceModel {
  int? id;
  String? serviceLabel;
  String? infosUrl;
  String? ticketImageUrl;
  String? ticketOptionalMessage;
  String? serviceInfos;
  String? serviceName;
  int? serviceId;
  int? visibleInOowoo;
  String? serviceThumbnail;
  int? serviceTypeId;
  int? actualDistance;
  int? nextTime;
  int? averageTime;
  double? price;
  double? indicativePrice;
  String? currency;
  int? maxDelayCancel;
  int? requiredPayment;
  int? requiredConfirmation;
  int? requiredUserLocation;
  String? utcModifier;
  late List<SubCatModel> subCats;

  PlaceModel? placeInfo;
  //Case model from qr
  ProsModel? proInfo;

  ProServiceModel({
    this.id,
    this.serviceLabel,
    this.infosUrl,
    this.ticketImageUrl,
    this.ticketOptionalMessage,
    this.actualDistance,
    this.price,
    this.indicativePrice,
    this.currency,
    this.nextTime,
    this.averageTime,
    this.maxDelayCancel,
    this.placeInfo,
    this.serviceInfos,
    this.serviceName,
    this.serviceThumbnail,
    this.visibleInOowoo,
    this.requiredPayment,
    this.requiredUserLocation,
    this.requiredConfirmation,
    this.serviceId,
    this.utcModifier,
    required this.subCats,
    this.proInfo,
  });

  bool get isQueue =>
      serviceTypeId == CT_QUEUE_LINKED_PLACE ||
      serviceTypeId == CT_QUEUE_NOT_LINKED_PLACE;

  bool get isRequirePayment => requiredPayment == 1;

  bool get isRequireAddress => requiredUserLocation == 1;

  bool get isSoldOut => nextTime == null || nextTime! <= 0;

  ProServiceModel.fromJson(Map<String, dynamic> json) {
    id = json['id'];
    utcModifier = json['utcModifier'];
    serviceLabel = json['serviceLabel'] ?? '';
    infosUrl = json['infosUrl'] ?? '';
    ticketImageUrl = json['ticketImageUrl'] ?? '';
    ticketOptionalMessage = json['ticketOptionalMessage'] ?? '';
    actualDistance = json['actualDistance'];
    price = json['price'] ?? 0.0;
    indicativePrice = json['indicativePrice'] ?? 0.0;
    currency = json['currency'] ?? '';
    nextTime = json['nextTime'] ?? 0;
    averageTime = json['averageTime'] ?? 0;
    serviceInfos = json['serviceInfos'] ?? '';
    serviceName = json['serviceName'] ?? '';
    serviceId = json['serviceId'] ?? json['id'] ?? 0;
    maxDelayCancel = json['maxDelayCancel'] ?? 0;
    serviceTypeId = json['serviceTypeId'] ?? 0;
    visibleInOowoo = json['visibleInOowoo'] ?? 0;
    serviceThumbnail = json['serviceThumbnail'] ?? '/thumbnails/default.png';
    requiredPayment = json['requiredPayment'] ?? 0;
    requiredUserLocation = json['requiredUserLocation'] ?? 0;
    requiredConfirmation = json['requiredConfirmation'] ?? 0;
    placeInfo = PlaceModel.fromJson(json['placeInfo'] ?? {});
    subCats = (json['subcat'] ?? [])
        .map<SubCatModel>((e) => SubCatModel.fromJson(e))
        .toList();
    if (json['proInfo'] != null) proInfo = ProsModel.fromJson(json['proInfo']);
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = {};
    data['subcat'] = subCats.map((e) => e.toJson()).toList();
    data['placeInfo'] = placeInfo?.toJson();
    data['id'] = id;
    data['visibleInOowoo'] = visibleInOowoo;
    data['serviceTypeId'] = serviceTypeId;
    data['maxDelayCancel'] = maxDelayCancel;
    data['serviceInfos'] = serviceInfos;
    data['utcModifier'] = utcModifier;
    data['serviceName'] = serviceName;
    data['serviceThumbnail'] = serviceThumbnail;
    data['serviceLabel'] = serviceLabel;
    data['infosUrl'] = infosUrl;
    data['ticketImageUrl'] = ticketImageUrl;
    data['ticketOptionalMessage'] = ticketOptionalMessage;
    data['actualDistance'] = actualDistance;
    data['price'] = price;
    data['indicativePrice'] = indicativePrice;
    data['currency'] = currency;
    data['nextTime'] = nextTime;
    data['averageTime'] = averageTime;
    data['serviceId'] = serviceId;
    data['requiredPayment'] = requiredPayment;
    data['requiredUserLocation'] = requiredUserLocation;
    data['requiredConfirmation'] = requiredConfirmation;
    data['proInfo'] = proInfo?.toJson();
    return data;
  }
}

class SubCatModel {
  late String subcatName;
  late String subcatTranslation;
  late int id;
  bool select = false;
  late String color;
  String? pictureUrl;

  SubCatModel({
    required this.id,
    required this.subcatTranslation,
    required this.subcatName,
    required this.color,
    this.pictureUrl,
  });

  SubCatModel.fromJson(Map<String, dynamic> json) {
    subcatName = json['subcatName'] ?? '';
    subcatTranslation = json['subcatTranslation'] ?? '';
    id = json['id'];
    color = json['colorCode'] ?? 'FFFFFF';
    pictureUrl = json['pictureUrl'];
  }

  SubCatModel.empty() {
    subcatTranslation = '';
    id = 0;
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['subcatName'] = this.subcatName;
    data['subcatTranslation'] = this.subcatTranslation;
    data['id'] = this.id;
    data['colorCode'] = this.color;
    data['pictureUrl'] = this.pictureUrl;
    return data;
  }
}
